aboutsummaryrefslogtreecommitdiff
path: root/helper
diff options
context:
space:
mode:
authorOla Liljedahl <ola.liljedahl@linaro.org>2015-01-07 17:23:58 +0100
committerMike Holmes <mike.holmes@linaro.org>2015-01-07 12:05:50 -0500
commite034782a72075a654e8186997eb6e94b3e322ac0 (patch)
tree63bed49d3903f0e3eb6d5dfb5f79b477afa03704 /helper
parentfd46d82eb9f12405d919a0a45e6745391c52e18b (diff)
api: odp_system_info.h: change core to cpu everywhere
Rename odp_core_count() to odp_cpu_count(). Change "core" to "cpu"/"CPU" in messages and comments. Signed-off-by: Ola Liljedahl <ola.liljedahl@linaro.org> Reviewed-by: Petri Savolainen <petri.savolainen@linaro.org> Signed-off-by: Mike Holmes <mike.holmes@linaro.org>
Diffstat (limited to 'helper')
-rw-r--r--helper/include/odph_linux.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/helper/include/odph_linux.h b/helper/include/odph_linux.h
index 8671dc0..4ed8bbe 100644
--- a/helper/include/odph_linux.h
+++ b/helper/include/odph_linux.h
@@ -30,14 +30,14 @@ extern "C" {
typedef struct {
pthread_t thread; /**< Pthread ID */
pthread_attr_t attr; /**< Pthread attributes */
- int core; /**< Core ID */
+ int cpu; /**< CPU ID */
} odph_linux_pthread_t;
/** Linux process state information */
typedef struct {
pid_t pid; /**< Process ID */
- int core; /**< Core ID */
+ int cpu; /**< CPU ID */
int status; /**< Process state change status */
} odph_linux_process_t;
@@ -45,17 +45,17 @@ typedef struct {
/**
* Creates and launches pthreads
*
* Creates, pins and launches num threads to separate cores starting from
* first_core.
*
* @param thread_tbl Thread table
* @param num Number of threads to create
* @param first_core First physical core
* @param start_routine Thread start function
* @param arg Thread argument
*/
void odph_linux_pthread_create(odph_linux_pthread_t *thread_tbl,
- int num, int first_core,
+ int num, int first_cpu,
void *(*start_routine) (void *), void *arg);
@@ -74,31 +74,31 @@ void odph_linux_pthread_join(odph_linux_pthread_t *thread_tbl, int num);
/**
* Fork a process
*
* Forks and sets core affinity for the child process
*
* @param proc Pointer to process state info (for output)
* @param core Destination core for the child process
*
* @return On success: 1 for the parent, 0 for the child
* On failure: -1 for the parent, -2 for the child
*/
-int odph_linux_process_fork(odph_linux_process_t *proc, int core);
+int odph_linux_process_fork(odph_linux_process_t *proc, int cpu);
/**
* Fork a number of processes
*
* Forks and sets core affinity for child processes
*
* @param proc_tbl Process state info table (for output)
* @param num Number of processes to create
* @param first_core Destination core for the first process
*
* @return On success: 1 for the parent, 0 for the child
* On failure: -1 for the parent, -2 for the child
*/
int odph_linux_process_fork_n(odph_linux_process_t *proc_tbl,
- int num, int first_core);
+ int num, int first_cpu);
/**
@@ -45,17 +45,17 @@ typedef struct {
* Creates and launches pthreads
*
- * Creates, pins and launches num threads to separate cores starting from
- * first_core.
+ * Creates, pins and launches num threads to separate CPU's starting from
+ * first_cpu.
*
* @param thread_tbl Thread table
@@ -45,17 +45,17 @@ typedef struct {
* @param thread_tbl Thread table
* @param num Number of threads to create
- * @param first_core First physical core
+ * @param first_cpu First physical CPU
* @param start_routine Thread start function
* @param arg Thread argument
@@ -74,31 +74,31 @@ void odph_linux_pthread_join(odph_linux_pthread_t *thread_tbl, int num);
* Fork a process
*
- * Forks and sets core affinity for the child process
+ * Forks and sets CPU affinity for the child process
*
* @param proc Pointer to process state info (for output)
@@ -74,31 +74,31 @@ void odph_linux_pthread_join(odph_linux_pthread_t *thread_tbl, int num);
*
* @param proc Pointer to process state info (for output)
- * @param core Destination core for the child process
+ * @param cpu Destination CPU for the child process
*
* @return On success: 1 for the parent, 0 for the child
@@ -74,31 +74,31 @@ void odph_linux_pthread_join(odph_linux_pthread_t *thread_tbl, int num);
* Fork a number of processes
*
- * Forks and sets core affinity for child processes
+ * Forks and sets CPU affinity for child processes
*
* @param proc_tbl Process state info table (for output)
@@ -74,31 +74,31 @@ void odph_linux_pthread_join(odph_linux_pthread_t *thread_tbl, int num);
* @param proc_tbl Process state info table (for output)
* @param num Number of processes to create
- * @param first_core Destination core for the first process
+ * @param first_cpu Destination CPU for the first process
*
* @return On success: 1 for the parent, 0 for the child